#[repr(C)]pub struct SessionUnregisterForTxResponse {
pub successful: u8,
pub status: i32,
}Fields
successful: u8status: i32Trait Implementations
Sourceimpl Clone for SessionUnregisterForTxResponse
impl Clone for SessionUnregisterForTxResponse
Sourcefn clone(&self) -> SessionUnregisterForTxResponse
fn clone(&self) -> SessionUnregisterForTxResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<SessionUnregisterForTxResponse, D> for SessionUnregisterForTxResponse
impl<D: ResourceDialect> Decode<SessionUnregisterForTxResponse, D> for SessionUnregisterForTxResponse
Sourceimpl<D: ResourceDialect> Encode<SessionUnregisterForTxResponse, D> for &SessionUnregisterForTxResponse
impl<D: ResourceDialect> Encode<SessionUnregisterForTxResponse, D> for &SessionUnregisterForTxResponse
Sourceimpl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<i32, D>> Encode<SessionUnregisterForTxResponse, D> for (T0, T1)
impl<D: ResourceDialect, T0: Encode<u8, D>, T1: Encode<i32, D>> Encode<SessionUnregisterForTxResponse, D> for (T0, T1)
Sourceimpl Ord for SessionUnregisterForTxResponse
impl Ord for SessionUnregisterForTxResponse
Sourcefn cmp(&self, other: &SessionUnregisterForTxResponse) -> Ordering
fn cmp(&self, other: &SessionUnregisterForTxResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for SessionUnregisterForTxResponse
impl PartialEq for SessionUnregisterForTxResponse
Sourcefn eq(&self, other: &SessionUnregisterForTxResponse) -> bool
fn eq(&self, other: &SessionUnregisterForTxResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for SessionUnregisterForTxResponse
impl PartialOrd for SessionUnregisterForTxResponse
Sourceimpl TypeMarker for SessionUnregisterForTxResponse
impl TypeMarker for SessionUnregisterForTxResponse
Sourcetype Owned = SessionUnregisterForTxResponse
type Owned = SessionUnregisterForTxResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for SessionUnregisterForTxResponse
impl ValueTypeMarker for SessionUnregisterForTxResponse
Sourcetype Borrowed<'a> = &'a SessionUnregisterForTxResponse
type Borrowed<'a> = &'a SessionUnregisterForTxResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreimpl Copy for SessionUnregisterForTxResponse
impl Eq for SessionUnregisterForTxResponse
impl Persistable for SessionUnregisterForTxResponse
impl StructuralPartialEq for SessionUnregisterForTxResponse